==> cria-0.0.1-src.tar.gz: cria-0.0.1-src/src/Cria/source/StringBuffer.h <==
/*
 *  $Id: StringBuffer.h 362 2009-08-29 03:27:33Z oicawa $
 *
 *  ===============================================================================
 *
 *   Copyright (C) 2008-2009  Masamitsu Oikawa  <oicawa@gmail.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in
 *   all copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *   THE SOFTWARE.
 *
 *  ===============================================================================
 */

 
#ifndef PUBLIC_STRINGBUFFER_H_INCLUDED
#define PUBLIC_STRINGBUFFER_H_INCLUDED


#include "Cria.h"
#include "List.h"
#include "String.h"


#define STRING_BUFFER_SIZE  256



StringBuffer
StringBuffer_new(
);



void
StringBuffer_appendChar(
    StringBuffer    stringBuffer,
    char            charactor
);



void
StringBuffer_append(
    StringBuffer    stringBuffer,
    char*           string
);



String
StringBuffer_toString(
    StringBuffer    stringBuffer
);



#endif

==> cria-0.0.2-src.tar.gz: cria-0.0.2-src/src/Cria/source/StringBuffer.h <==
/*
 *  $Id: StringBuffer.h 368 2009-09-14 13:24:28Z oicawa $
 *
 *  ===============================================================================
 *
 *   Copyright (C) 2008-2009  Masamitsu Oikawa  <oicawa@gmail.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in
 *   all copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *   THE SOFTWARE.
 *
 *  ===============================================================================
 */

 
#ifndef PUBLIC_STRINGBUFFER_H_INCLUDED
#define PUBLIC_STRINGBUFFER_H_INCLUDED


#include "Cria.h"
#include "List.h"
#include "String.h"


#define STRING_BUFFER_SIZE  256



StringBuffer
StringBuffer_new(
);



void
StringBuffer_appendChar(
    StringBuffer    stringBuffer,
    wchar_t        charactor
);



void
StringBuffer_append(
    StringBuffer    stringBuffer,
    String          string
);



String
StringBuffer_toString(
    StringBuffer    stringBuffer
);



#endif
